﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Diagnostics.Tracing;
using System.Linq;
using System.Threading.Tasks;

namespace EventMakerRazor.Models
{
    public class Event
    {
        public int Id { get; set; }

        [Display(Name = "Event Name")]
        [Required(ErrorMessage = "Name of the Event is required"), MaxLength(30)]
        public string Name { get; set; }
        public string Description { get; set; }

        [Required]
        [StringLength(18, ErrorMessage ="Name of the City can not be longer than 18 chars")]
        public string City { get; set; }

        [Required(ErrorMessage = "The date is required")]
        //[Range(typeof(DateTime), "1/11/2020", "1/11/2021", ErrorMessage = "Date must be in the future but maximum one year")]
        [CustomDateRange(ErrorMessage= "Date must be in the future but max 1 year")]
        public DateTime DateTime { get; set; }

        public Event()
        {
            
        }

        public Event(string name, string description, string city, DateTime dateTime)
        {
            Name = name;
            Description = description;
            City = city;
            DateTime = dateTime;
        }
    }

    class CustomDateRangeAttribute : RangeAttribute
    {
        public CustomDateRangeAttribute() : base(typeof(DateTime), DateTime.Now.ToString(), DateTime.Now.AddYears(1).ToString())
        { }
    }
}
